==> qtwebengine-everywhere-opensource-src-6.2.7.zip: qtwebengine-everywhere-src-6.2.7/src/3rdparty/chromium/chrome/browser/resources/history/history.ts <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './app.js';

export {CrActionMenuElement} from 'chrome://resources/cr_elements/cr_action_menu/cr_action_menu.js';
export {CrDialogElement} from 'chrome://resources/cr_elements/cr_dialog/cr_dialog.m.js';
export {ensureLazyLoaded, HistoryAppElement, listenForPrivilegedLinkClicks} from './app.js';
export {BrowserService, BrowserServiceImpl, QueryResult, RemoveVisitsRequest} from './browser_service.js';
export {HistoryPageViewHistogram, SYNCED_TABS_HISTOGRAM_NAME, SyncedTabsHistogram} from './constants.js';
export {ForeignSession, ForeignSessionTab, ForeignSessionWindow, HistoryEntry, HistoryQuery} from './externs.js';
export {BrowserProxyImpl} from './history_clusters/browser_proxy.js';
export {PageCallbackRouter, PageHandlerRemote} from './history_clusters/history_clusters.mojom-webui.js';
export {ClusterAction, RelatedSearchAction, VisitAction, VisitType} from './history_clusters/metrics_proxy.js';
export {MetricsProxy, MetricsProxyImpl} from './history_clusters/metrics_proxy.js';
export {HistoryItemElement} from './history_item.js';
export {ActionMenuModel, HistoryListElement} from './history_list.js';
export {HistoryToolbarElement} from './history_toolbar.js';
export {HistorySearchedLabelElement} from './searched_label.js';
export {HistorySideBarElement} from './side_bar.js';
export {HistorySyncedDeviceCardElement} from './synced_device_card.js';
export {HistorySyncedDeviceManagerElement} from './synced_device_manager.js';

==> qtwebengine-everywhere-opensource-src-6.5.4.zip: qtwebengine-everywhere-src-6.5.4/src/3rdparty/chromium/chrome/browser/resources/history/history.ts <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './app.js';

export {BrowserProxyImpl} from 'chrome://resources/cr_components/history_clusters/browser_proxy.js';
export {ClusterAction, PageCallbackRouter, PageHandlerRemote, RelatedSearchAction, VisitAction, VisitType} from 'chrome://resources/cr_components/history_clusters/history_clusters.mojom-webui.js';
export {MetricsProxy, MetricsProxyImpl} from 'chrome://resources/cr_components/history_clusters/metrics_proxy.js';
export {CrActionMenuElement} from 'chrome://resources/cr_elements/cr_action_menu/cr_action_menu.js';
export {CrDialogElement} from 'chrome://resources/cr_elements/cr_dialog/cr_dialog.js';
export {ensureLazyLoaded, HistoryAppElement, listenForPrivilegedLinkClicks} from './app.js';
export {BrowserService, BrowserServiceImpl, QueryResult, RemoveVisitsRequest} from './browser_service.js';
export {HistoryPageViewHistogram, SYNCED_TABS_HISTOGRAM_NAME, SyncedTabsHistogram} from './constants.js';
export {ForeignSession, ForeignSessionTab, ForeignSessionWindow, HistoryEntry, HistoryQuery} from './externs.js';
export {HistoryItemElement} from './history_item.js';
export {ActionMenuModel, HistoryListElement} from './history_list.js';
export {HistoryToolbarElement} from './history_toolbar.js';
export {HistorySearchedLabelElement} from './searched_label.js';
export {HistorySideBarElement} from './side_bar.js';
export {HistorySyncedDeviceCardElement} from './synced_device_card.js';
export {HistorySyncedDeviceManagerElement} from './synced_device_manager.js';
